import { Component, Input } from '@angular/core';
import { ActivatedRoute, ChildrenOutletContexts, NavigationStart, Router, RouterModule } from '@angular/router';
import { slideInAnimation } from '../../animations';
import { CommonNzModule } from '../../common.nz.module';
import { IPath } from '../../pages/manager/auth/routes/route.service';

interface IPathEnhance extends IPath {
  label: string;
  path: string;
  minWith?: number;
}

@Component({
  selector: 'secondary-tabs',
  standalone: true,
  imports: [RouterModule, CommonNzModule],
  templateUrl: './secondary-tabs.component.html',
  styleUrl: './secondary-tabs.component.less',
  animations: [slideInAnimation],
})
export class SecondaryTabsComponent {
  @Input() paths: IPathEnhance[] = [];
  @Input() parentMatchString: string = '';
  constructor(
    private router: Router,
    private readonly route: ActivatedRoute,
    private contexts: ChildrenOutletContexts
  ) {
    this.router.events.subscribe(event => {
      if (event instanceof NavigationStart) {
        if (event.url === this.parentMatchString) {
          this.resetActiveTab();
        }
      }
    });
  }
  getRouteAnimationData() {
    return this.contexts.getContext('primary')?.route?.snapshot?.data?.['animation'];
  }
  ngOnInit() {
    if (this.isNoTargetPage()) {
      this.resetActiveTab();
    }
  }
  isNoTargetPage() {
    return this.router.url === this.parentMatchString;
  }
  resetActiveTab() {
    if (this.paths[0]) {
      this.navigateTo(this.paths[0]);
    }
  }
  navigateTo(path: IPath) {
    this.router.navigate([path.path], { relativeTo: this.route });
  }
}
